    .. _extern:

coherence.extern (package)
==========================

The coherence.extern package contains some external dependencies included into
this project. Those external dependencies are included because the source code
may be slightly different from the original projects, don't have an installer,
are unmaintained...

Some of this external dependencies may be replaced or removed depending on the
status of the Cohen3 project.

.. toctree::

    extern/covers_by_amazon
    extern/db_row
    extern/simple_plugin
    extern/xdg

coherence.extern.galleryremote (package)
----------------------------------------

.. toctree::

    extern/galleryremote/gallery

coherence.extern.youtubedl (package)
------------------------------------

.. toctree::
    extern/youtubedl/youtubedl
